# OIDCProxyContentManipulation

The configuration of the content on which proxy will perform substitution.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**media_types** | [**list[OIDCContentType]**](OIDCContentType.md) | The list of media types (MIME types) on which the proxy will perform content substitution. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


